@@ -1,36 +1,7 @@
 from pathlib import Path
 
 
-def _load_default_texts():
-    """
-    Loads default general texts
 
-    Returns
-    -------
-    result : default wikipedia texts
-    """
-    file_name = "preprocessed_datasets/20newsgroup_validation/corpus.txt"
-    result = []
-    file = Path(file_name)
-    if file.is_file():
-        with open(file_name, 'r') as corpus_file:
-            for line in corpus_file:
-                result.append(line.split())
-        return result
-    return False
-
-
-'''
-# METRICS PARAMETERS #
-'''
-em_coherence = {'texts': _load_default_texts(), 'topk': 10,
-                'measure': 'c_npmi'}
-em_coherence_we = {'topk': 10, 'word2vec_path': None, 'binary': False}
-em_coherence_we_pc = {'topk': 10, 'w2v_model': None}
-em_topic_diversity = {'topk': 10}
-em_invertedRBO = {'topk': 10, 'weight': 0.9}
-em_word_embeddings_invertedRBO = {'topk': 10, 'weight': 0.9}
-em_f1_score = {'average': 'micro', 'use_log': False}
 
 '''
 # MODELS PARAMETERS #
